@@ -1,3 +1,6 @@
+from pathlib import Path
+from typing import Any, Mapping
+
 from playwright._impl._api_structures import (
     Cookie,
     Geolocation,
@@ -7,8 +10,8 @@ from playwright._impl._api_structures import (
     ViewportSize,
 )
 
-from wrighter import async_wrighter, constants, core, options, plugin, plugins, sync_wrighter
+from wrighter import constants, core, plugins
 from wrighter.async_wrighter import AsyncWrighter
-from wrighter.options import WrighterOptions
+from wrighter.options import WrighterOptions, load_wrighter_opts
 from wrighter.plugin import Plugin
 from wrighter.sync_wrighter import SyncWrighter
