@@ -1,15 +1,16 @@
 from playwright.sync_api import Page, Route
-from stdl.dt import fmt_datetime
 from stdl.str_u import FG, colored
 
-from wrighter.constants import RESOURCE_TYPES
 from wrighter.plugin import Plugin
 
 DEFAULT_RESOURCE_EXCLUSIONS = ["image", "stylesheet", "media", "font", "other"]
 
 
 class ResourceBlocker(Plugin):
-    """Block requests with specified resource types"""
+    """
+    A plugin that blocks requests with specified resource types.
+    For example, you can block all images, stylesheets, fonts, etc. from being loaded on a page.
+    """
 
     def __init__(
         self,
@@ -20,9 +21,6 @@ class ResourceBlocker(Plugin):
         self.url_pattern = url_pattern
         self.blocked_resoruces = blocked_resources
         self.verbose = verbose
-        for i in self.blocked_resoruces:
-            if i not in RESOURCE_TYPES:
-                raise ValueError(i)
 
         super().__init__()
 
